==> mysql-connector-net-8.0.22-src.zip: EFCore/src/Metadata/MySQLValueGenerationStrategy.cs <==
﻿// Copyright (c) 2020 Oracle and/or its affiliates.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

namespace MySql.Data.EntityFrameworkCore.Metadata
{
  /// <summary>
  ///     Defines two strategies to use across the EF Core stack when generating key values
  ///     from MySQL Server database columns.
  /// </summary>
  public enum MySQLValueGenerationStrategy
  {
    /// <summary>
    ///   No specific MySQL Server strategy
    /// </summary>
    None,
    /// <summary>
    ///   A pattern that uses a standard MySQL Server <c>Identity</c> column in the same way as EF6 and previous frameworks.
    /// </summary>
    IdentityColumn,
    /// <summary>
    ///   Values of a generated column are computed from an expression included in the column definition.
    /// </summary>
    ComputedColumn
  }
}

==> mysql-connector-net-8.0.29-src.zip: EFCore/src/Metadata/MySQLValueGenerationStrategy.cs <==
﻿// Copyright (c) 2020 Oracle and/or its affiliates.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

namespace MySql.EntityFrameworkCore.Metadata
{
  /// <summary>
  ///     Defines two strategies to use across the EF Core stack when generating key values
  ///     from MySQL Server database columns.
  /// </summary>
  public enum MySQLValueGenerationStrategy
  {
    /// <summary>
    ///   No specific MySQL Server strategy
    /// </summary>
    None,
    /// <summary>
    ///   A pattern that uses a standard MySQL Server <c>Identity</c> column in the same way as EF6 and previous frameworks.
    /// </summary>
    IdentityColumn,
    /// <summary>
    ///   Values of a generated column are computed from an expression included in the column definition.
    /// </summary>
    ComputedColumn
  }
}
